<?php
	get_template_part('panel/constants');

	load_theme_textdomain( 'ci_theme', get_template_directory() . '/lang' );

	// This is the main options array. Can be accessed as a global in order to reduce function calls.
	$ci = get_option(THEME_OPTIONS);
	$ci_defaults = array();

	// The $content_width needs to be before the inclusion of the rest of the files, as it is used inside of some of them.
	if ( ! isset( $content_width ) ) $content_width = 750;

	//
	// Let's bootstrap the theme.
	//
	get_template_part('panel/bootstrap');
	get_template_part('functions/woocommerce');

	//
	// Let WordPress manage the title.
	//
	add_theme_support( 'title-tag' );

	// Enable HTML5 support
	add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list', 'gallery', 'caption' ) );

	//
	// Define our various image sizes.
	// Notice: Changing the values below requires running a thumbnail regeneration
	// plugin such as "Regenerate Thumbnails" (http://wordpress.org/plugins/regenerate-thumbnails/)
	// in order for the new dimensions to take effect.
	//
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 750, 430, true );
	add_image_size( 'ci_thumb_uncropped', 750 );
	add_image_size( 'ci_slider_full', 1920, 550, true );
	add_image_size( 'ci_item_thumb', 750, 560, true );
	add_image_size( 'ci_listing_team', 500, 500, true );

	add_image_size( 'ci_widget_testimonial', 130, 130, true );
	add_image_size( 'ci_widget_split_custom', 555, 380, true );

	// Let the user choose a color scheme on each post individually.
	add_ci_theme_support('post-color-scheme', array( 'page', 'post', 'cpt_feature', 'cpt_partner', 'cpt_portfolio', 'cpt_service', 'cpt_team' ) );


	// Let WooCommerce know that we support it.
	add_theme_support( 'woocommerce', array(
		'thumbnail_image_width'         => 750,
		'single_image_width'            => 750,
		'gallery_thumbnail_image_width' => 200,
	) );

	add_filter( 'the_content', 'ci_prettyPhoto_rel', 12 );
	add_filter( 'get_comment_text', 'ci_prettyPhoto_rel' );
	add_filter( 'wp_get_attachment_link', 'ci_prettyPhoto_rel' );
	if( !function_exists('ci_prettyPhoto_rel') ):
	function ci_prettyPhoto_rel($content)
	{
		global $post;
		$pattern = "/<a(.*?)href=('|\")([^>]*).(bmp|gif|jpeg|jpg|png)('|\")(.*?)>(.*?)<\/a>/i";

		$replacement = '<a$1href=$2$3.$4$5 data-rel="prettyPhoto[' . $post->ID . ']"$6>$7</a>';

		$content = preg_replace( $pattern, $replacement, $content );

		return $content;
	}
	endif;


	if ( !function_exists( 'ci_get_read_more_text' ) ):
	function ci_get_read_more_text( $post_type ) {
		$wording = ci_setting( 'read_more_text' );

		if( !in_array( $post_type, array('post', 'page', 'attachment') ) ) {
			$tmp = ci_setting( 'read_more_text_' . $post_type );
			if( !empty( $tmp ) ) {
				$wording = $tmp;
			}
		}

		return $wording;
	}
	endif;


	if ( ! function_exists( 'ci_theme_get_columns_classes' ) ):
	function ci_theme_get_columns_classes( $columns ) {
		switch ( intval( $columns ) ) {
			case 1:
				$classes = 'col-md-12 col-sm-6';
				break;
			case 2:
				$classes = 'col-md-6 col-sm-6';
				break;
			case 4:
				$classes = 'col-md-3 col-sm-6';
				break;
			case 3:
			default:
				$classes = 'col-md-4 col-sm-6';
				break;
		}

		return $classes;
	}
	endif;

	if ( ! defined( 'CI_THEME_WHITELABEL' ) || false === (bool) CI_THEME_WHITELABEL ) {
		add_filter( 'ocdi/import_files', 'ci_theme_ocdi_import_files' );
		add_action( 'ocdi/after_import', 'ci_theme_ocdi_after_import_setup' );
	}

	function ci_theme_ocdi_import_files( $files ) {
		if ( ! defined( 'CI_THEME_NAME' ) ) {
			define( 'CI_THEME_NAME', 'space9' );
		}

		$demo_dir_url = untrailingslashit( apply_filters( 'ci_theme_ocdi_demo_dir_url', 'https://www.cssigniter.com/sample_content/' . CI_THEME_NAME ) );

		// When having more that one predefined imports, set a preview image, preview URL, and categories for isotope-style filtering.
		$new_files = array(
			array(
				'import_file_name'           => esc_html__( 'Demo Import', 'ci_theme' ),
				'import_file_url'            => $demo_dir_url . '/content.xml',
				'import_widget_file_url'     => $demo_dir_url . '/widgets.wie',
			),
		);

		return array_merge( $files, $new_files );
	}

	function ci_theme_ocdi_after_import_setup() {
		// Set up nav menus.
		$main_menu      = get_term_by( 'name', 'main', 'nav_menu' );
		$secondary_menu = get_term_by( 'name', 'footer', 'nav_menu' );

		set_theme_mod( 'nav_menu_locations', array(
			'ci_main_menu'      => $main_menu->term_id,
			'ci_footer_menu'    => $secondary_menu->term_id,
		) );

		// Set up home and blog pages.
		$front_page_id = get_page_by_title( 'Homepage' );
		$blog_page_id  = get_page_by_title( 'Blog' );

		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', $front_page_id->ID );
		update_option( 'page_for_posts', $blog_page_id->ID );

		// Try to force a term recount.
		// wp_defer_term_counting( false ) doesn't work properly as there are post imported from different AJAX requests.
		$taxonomies = get_taxonomies( array(), 'names' );
		foreach ( $taxonomies as $taxonomy ) {
			$terms             = get_terms( $taxonomy, array( 'hide_empty' => false ) );
			$term_taxonomy_ids = wp_list_pluck( $terms, 'term_taxonomy_id' );

			wp_update_term_count( $term_taxonomy_ids, $taxonomy );
		}
	}

	/**
	 *  Common theme features.
	 */
	require_once get_theme_file_path( '/common/common.php' );
