<?php
//
// Features Post Type related functions.
//
add_action( 'init', 'ci_create_cpt_feature' );
add_action( 'admin_init', 'ci_add_cpt_feature_meta' );
add_action( 'save_post', 'ci_update_cpt_feature_meta' );

if ( ! function_exists( 'ci_create_cpt_feature' ) ) :
function ci_create_cpt_feature() {
	$labels = array(
		'name'               => _x( 'Features', 'post type general name', 'ci_theme' ),
		'singular_name'      => _x( 'Feature', 'post type singular name', 'ci_theme' ),
		'add_new'            => __( 'Add New', 'ci_theme' ),
		'add_new_item'       => __( 'Add New Feature', 'ci_theme' ),
		'edit_item'          => __( 'Edit Feature', 'ci_theme' ),
		'new_item'           => __( 'New Feature', 'ci_theme' ),
		'view_item'          => __( 'View Feature', 'ci_theme' ),
		'search_items'       => __( 'Search Features', 'ci_theme' ),
		'not_found'          => __( 'No Features found', 'ci_theme' ),
		'not_found_in_trash' => __( 'No Features found in the trash', 'ci_theme' ),
		'parent_item_colon'  => ''
	);

	$args = array(
		'labels'          => $labels,
		'singular_label'  => __( 'Feature', 'ci_theme' ),
		'public'          => true,
		'show_ui'         => true,
		'capability_type' => 'post',
		'hierarchical'    => false,
		'has_archive'     => false,
		'rewrite'         => array( 'slug' => _x( 'feature', 'post type slug', 'ci_theme' ) ),
		'menu_position'   => 5,
		'supports'        => array( 'title', 'editor', 'thumbnail', 'excerpt' ),
		'menu_icon'       => 'dashicons-list-view'
	);

	register_post_type( 'cpt_feature' , $args );
}
endif;


if ( ! function_exists('ci_add_cpt_feature_meta') ) :
function ci_add_cpt_feature_meta() {
	add_meta_box('ci_cpt_feature_meta', __('Feature Details', 'ci_theme'), 'ci_add_cpt_feature_meta_box', 'cpt_feature', 'normal', 'high');
}
endif;

if ( ! function_exists( 'ci_update_cpt_feature_meta' ) ):
function ci_update_cpt_feature_meta( $post_id )	{
	if ( ! ci_can_save_meta('cpt_feature') ) return;

	update_post_meta( $post_id, 'ci_cpt_featured_position', sanitize_key( $_POST['ci_cpt_featured_position'] ) );
	update_post_meta( $post_id, 'ci_cpt_icon', sanitize_html_class( $_POST[ 'ci_cpt_icon' ] ) );
}
endif;

if ( ! function_exists( 'ci_add_cpt_feature_meta_box' ) ) :
function ci_add_cpt_feature_meta_box() {
	ci_prepare_metabox( 'cpt_feature' );

	$opts = array(
		'top'   => __( 'On top (Fullwidth)', 'ci_theme' ),
		'left'  => __( 'On the left of the content', 'ci_theme' ),
		'right' => __( 'On the right of the content', 'ci_theme' ),
	);
	ci_metabox_dropdown('ci_cpt_featured_position', $opts, __('Featured Image Position:', 'ci_theme'));

	ci_metabox_input( 'ci_cpt_icon', sprintf( __( 'Enter an icon code for this post. You can use any icons listed in the <a href="%s" target="_blank">FontAwesome Icon Page here.</a>. Enter the code exactly as you see it written, e.g. fa-support', 'ci_theme'), 'http://fontawesome.io/icons/'), array( 'default' => 'fa-bell' ));

}
endif;

?>