<?php
//
// Page Post Type related functions.
//
add_action( 'admin_init', 'ci_add_cpt_page_header_bg_meta' );
add_action( 'save_post', 'ci_update_cpt_page_header_bg_meta' );

if( !function_exists('ci_add_cpt_page_header_bg_meta') ):
function ci_add_cpt_page_header_bg_meta() {
	add_meta_box( 'ci_page_fixed_tpl_meta', __( 'Fixed layout', 'ci_theme' ), 'ci_add_page_fixed_tpl_meta_box', 'page', 'normal', 'high' );
	add_meta_box( 'ci_page_listing_meta', __( 'Listing Options', 'ci_theme' ), 'ci_add_page_listing_meta_box', 'page', 'normal', 'high' );
	add_meta_box( 'ci_page_contact_meta', __( 'Contact Options', 'ci_theme' ), 'ci_add_page_contact_meta_box', 'page', 'normal', 'high' );
}
endif;

if ( !function_exists('ci_update_cpt_page_header_bg_meta') ):
function ci_update_cpt_page_header_bg_meta($post_id) {

	if ( !ci_can_save_meta('page') ) return;

	update_post_meta( $post_id, 'page_layout', sanitize_key( $_POST['page_layout'] ) );

	$post_types = get_post_types( array('public' => true), 'names' );
	unset($post_types['attachment'], $post_types['page'], $post_types['cpt_testimonial'], $post_types['cpt_slider']);

	update_post_meta( $post_id, 'listing_post_type', in_array( $_POST['listing_post_type'], $post_types ) ? $_POST['listing_post_type'] : 'post' );
	update_post_meta( $post_id, 'listing_layout', in_array($_POST['listing_layout'], array('sidebar', 'columns')) ? $_POST['listing_layout'] : 'columns' );
	update_post_meta( $post_id, 'listing_columns', absint( $_POST['listing_columns'] ) );
	update_post_meta( $post_id, 'listing_posts_per_page', intval( $_POST['listing_posts_per_page'] ) );
	update_post_meta( $post_id, 'listing_isotope', ci_sanitize_checkbox( $_POST['listing_isotope'] ) );

	update_post_meta( $post_id, 'contact_map_lon', sanitize_text_field( $_POST['contact_map_lon'] ) );
	update_post_meta( $post_id, 'contact_map_lat', sanitize_text_field( $_POST['contact_map_lat'] ) );
	update_post_meta( $post_id, 'contact_map_title', sanitize_text_field( $_POST['contact_map_title'] ) );
	update_post_meta( $post_id, 'contact_map_tooltip', wp_kses_post( $_POST['contact_map_tooltip'] ) );
}
endif;

if( !function_exists('ci_add_page_fixed_tpl_meta_box') ):
function ci_add_page_fixed_tpl_meta_box( $object, $box ) {
	ci_prepare_metabox('page');

	?><p><?php _e('Select the desired layout of this page. This option overrides the global layout of your website, so it will always be shown according to your selected option below.', 'ci_theme'); ?></p><?php
	$options = array(
		'left'  => __( 'Sidebar on the left', 'ci_theme' ),
		'right' => __( 'Sidebar on the right', 'ci_theme' ),
		'full'  => __( 'Full width - No sidebar', 'ci_theme' ),
	);
	ci_metabox_dropdown('page_layout', $options, __('Fixed page layout', 'ci_theme'));

	ci_bind_metabox_to_page_template( 'ci_page_fixed_tpl_meta', 'template-page-fixed.php' );
}
endif;

if( !function_exists('ci_add_page_contact_meta_box') ):
function ci_add_page_contact_meta_box( $object, $box ) {
	ci_prepare_metabox('page');

	?><p><?php echo sprintf(__('In order to show a contact form in this page, you need to install, activate, and insert a form from one of the following plugins: <a href="%1$s" target="_blank">Contact Form 7</a>, <a href="%2$s" target="_blank">Jetpack</a>.', 'ci_theme'), 'https://wordpress.org/plugins/contact-form-7/', 'https://wordpress.org/plugins/jetpack/'); ?></p><?php

	?>
	<div class="postbox" style="margin-top:20px">
		<div class="handlediv" title="<?php esc_attr_e('Click to toggle', 'ci_theme'); ?>"><br></div>
		<h3 class="hndle"><?php _e('Map', 'ci_theme'); ?></h3>
		<div class="inside">

			<p><?php _e('Enter a place or address and press "Search". Alternatively, you can drag the marker to the desired position, or double click on the map to set a new location.', 'ci_theme'); ?></p>

			<fieldset class="gllpLatlonPicker">
				<input type="text" class="gllpSearchField">
				<input type="button" class="button gllpSearchButton" value="<?php _e('Search place/address', 'ci_theme'); ?>">

				<div class="gllpMap"><?php _e('Google Maps', 'ci_theme'); ?></div>

				<input type="hidden" class="gllpZoom" value="8"/>

				<?php
					ci_metabox_input( 'contact_map_lat', __( 'Location Latitude.', 'ci_theme' ), array(
						'input_class' => 'widefat gllpLatitude',
						'default'     => '36'
					) );
					ci_metabox_input( 'contact_map_lon', __( 'Location Longitude.', 'ci_theme' ), array(
						'input_class' => 'widefat gllpLongitude',
						'default'     => '-120'
					) );
				?>

				<input type="button" class="button gllpUpdateButton" value="<?php esc_attr_e('Update map', 'ci_theme'); ?>">

			</fieldset>

			<?php
				ci_metabox_input( 'contact_map_title', __( 'Map marker title:', 'ci_theme' ), array( 'default' => get_option( 'blogname' ) ) );
				ci_metabox_textarea( 'contact_map_tooltip', __( 'Map marker tooltip text (accepts HTML):', 'ci_theme' ) );
			?>
		</div><!-- /inside -->
	</div><!-- /postbox -->
	<?php

	ci_bind_metabox_to_page_template( 'ci_page_contact_meta', 'template-contact.php' );
}
endif;

if( !function_exists('ci_add_page_listing_meta_box') ):
function ci_add_page_listing_meta_box( $object, $box ) {
	ci_prepare_metabox('page');

	?><h2><?php _e('Content', 'ci_theme'); ?></h2><?php
	$post_types = get_post_types( array('public' => true), 'objects' );
	unset($post_types['attachment'], $post_types['page'], $post_types['cpt_testimonial'], $post_types['cpt_slider']);

	$options = array();
	foreach( $post_types as $key => $pt ) {
		$options[ $key ] = $pt->labels->name;
	}
	ci_metabox_dropdown('listing_post_type', $options, __('Post type to display:', 'ci_theme'));


	?><h2><?php _e('Layout', 'ci_theme'); ?></h2><?php
	ci_metabox_radio( 'listing_layout', 'll_columns', 'columns', __('Columns-based listing.', 'ci_theme'), array( 'default' => 'columns' ) );
		?><div class="inside"><?php
			$options = array();
			for ( $i = 2; $i <= 4; $i++ ) {
				$options[ $i ] = sprintf( _n( '1 Column', '%s Columns', $i, 'ci_theme' ), $i );
			}
			ci_metabox_dropdown( 'listing_columns', $options, __( 'Columns number:', 'ci_theme' ) );
			?><p><?php echo sprintf(__('Set the number of items per page that you want to display. Setting this to <strong>-1</strong> will show <em>all items</em>, while setting it to zero or leaving it empty, will follow the global option set from <em>Settings -> Reading</em>, currently set to <strong>%s items per page</strong>.', 'ci_theme'), get_option('posts_per_page')); ?></p><?php
			ci_metabox_input( 'listing_posts_per_page', __( 'Items per page:', 'ci_theme' ) );
			ci_metabox_checkbox( 'listing_isotope', 'on', __( 'Isotope effect (ignores <em>Items per page</em> setting.', 'ci_theme' ) );
		?></div><?php

	ci_metabox_radio( 'listing_layout', 'll_sidebar', 'sidebar', __('Sidebar-based listing.', 'ci_theme') );

	ci_bind_metabox_to_page_template( 'ci_page_listing_meta', 'template-listing.php' );
}
endif;
