<?php
//
// Portfolio Post Type related functions.
//
add_action( 'init', 'ci_create_cpt_portfolio' );
add_action( 'admin_init', 'ci_add_cpt_portfolio_meta' );
add_action( 'save_post', 'ci_update_cpt_portfolio_meta' );

if ( ! function_exists( 'ci_create_cpt_portfolio' ) ) :
function ci_create_cpt_portfolio() {
	$labels = array(
		'name'               => _x( 'Portfolio', 'post type general name', 'ci_theme' ),
		'singular_name'      => _x( 'Portfolio Item', 'post type singular name', 'ci_theme' ),
		'add_new'            => __( 'Add New', 'ci_theme' ),
		'add_new_item'       => __( 'Add New Portfolio Item', 'ci_theme' ),
		'edit_item'          => __( 'Edit Portfolio Item', 'ci_theme' ),
		'new_item'           => __( 'New Portfolio Item', 'ci_theme' ),
		'view_item'          => __( 'View Portfolio Item', 'ci_theme' ),
		'search_items'       => __( 'Search Portfolio Items', 'ci_theme' ),
		'not_found'          => __( 'No Portfolio Items found', 'ci_theme' ),
		'not_found_in_trash' => __( 'No Portfolio Items found in the trash', 'ci_theme' ),
		'parent_item_colon'  => __( 'Parent Portfolio Item:', 'ci_theme' )
	);

	$args = array(
		'labels'          => $labels,
		'singular_label'  => __( 'Portfolio Item', 'ci_theme' ),
		'public'          => true,
		'show_ui'         => true,
		'capability_type' => 'post',
		'hierarchical'    => false,
		'has_archive'     => _x( 'portfolio-archive', 'post type archive slug', 'ci_theme' ),
		'rewrite'         => array( 'slug' => _x( 'portfolio', 'post type slug', 'ci_theme' ) ),
		'menu_position'   => 5,
		'supports'        => array( 'title', 'editor', 'thumbnail', 'excerpt' ),
		'menu_icon'       => 'dashicons-portfolio'
	);

	register_post_type( 'cpt_portfolio' , $args );
}
endif;

if ( ! function_exists( 'ci_add_cpt_portfolio_meta' ) ) :
function ci_add_cpt_portfolio_meta() {
	add_meta_box('ci_cpt_portfolio_meta', __('Portfolio Details', 'ci_theme'), 'ci_add_cpt_portfolio_meta_box', 'cpt_portfolio', 'normal', 'high');
}
endif;

if ( ! function_exists( 'ci_update_cpt_portfolio_meta' ) ):
function ci_update_cpt_portfolio_meta( $post_id )	{
	if ( ! ci_can_save_meta( 'cpt_portfolio' ) ) return;

	update_post_meta( $post_id, "ci_cpt_video_url", esc_url_raw( $_POST["ci_cpt_video_url"] ) );
	update_post_meta( $post_id, "ci_cpt_portfolio_template", sanitize_key( $_POST["ci_cpt_portfolio_template"] ) );
	update_post_meta( $post_id, "ci_cpt_portfolio_project_fields", ci_theme_sanitize_portfolio_project_repeating( $_POST ) );
	ci_metabox_gallery_save( $_POST );
}
endif;

if ( ! function_exists( 'ci_add_cpt_portfolio_meta_box' ) ) :
function ci_add_cpt_portfolio_meta_box( $object, $box ) {
	ci_prepare_metabox( 'cpt_portfolio' );

	?><p><?php echo sprintf(__('If this is a video, you can simply enter the URL of a supported website\'s video. It needs to start with <strong>http://</strong> or <strong>https://</strong> (E.g. <em>%1$s</em>). A list of supported websites can be <a href="%2$s">found here</a>.', 'ci_theme'), 'https://www.youtube.com/watch?v=4Z9WVZddH9w', 'https://codex.wordpress.org/Embeds#Okay.2C_So_What_Sites_Can_I_Embed_From.3F'); ?></p><?php
	ci_metabox_input('ci_cpt_video_url', __('Video URL:', 'ci_theme'), array('esc_func' => 'esc_url'));

	?><h2><?php _e('Portfolio Gallery', 'ci_theme'); ?></h2>
	<p><?php _e('You can create a gallery for your portfolio item by pressing the "Add Images" button below. You should also set a featured image that will be used as this portfolio item\'s cover.', 'ci_theme'); ?></p><?php
	ci_metabox_gallery();

	?><p><?php _e('You can display your work in two different layouts: 1) Image Array (one image after the other) or 2) Image Slideshow.', 'ci_theme'); ?></p><?php
	$opts = array(
		'standard'      => __( 'Image Array', 'ci_theme' ),
		'standard-flex' => __( 'Image Slideshow', 'ci_theme' ),
	);
	ci_metabox_dropdown('ci_cpt_portfolio_template', $opts, __('Portfolio Template:', 'ci_theme'));

	?>
	<h2><?php _e( 'Project Details', 'ci_theme' ); ?></h2>
	<fieldset class="project_fields ci-repeating-fields">
		<div class="inner">
			<?php
				$fields = get_post_meta($object->ID, 'ci_cpt_portfolio_project_fields', true);
				if (!empty($fields)) {
					foreach( $fields as $field ) {
						?>
						<div class="post-field">
							<label><?php _e( 'Title:', 'ci_theme' ); ?> <input type="text" name="ci_cpt_portfolio_project_repeatable_title[]" value="<?php echo esc_attr( $field['title'] ); ?>" class="widefat" /></label>
							<label><?php _e( 'Description:', 'ci_theme' ); ?> <input type="text" name="ci_cpt_portfolio_project_repeatable_description[]" value="<?php echo esc_attr( $field['description'] ); ?>" class="widefat" /></label>
							<p class="ci-repeating-remove-action"><a href="#" class="button ci-repeating-remove-field"><i class="dashicons dashicons-dismiss"></i><?php _e( 'Remove me', 'ci_theme' ); ?></a></p>
						</div>
						<?php
					}
				}
				?>
				<div class="post-field field-prototype" style="display: none;">
					<label><?php _e( 'Title:', 'ci_theme' ); ?> <input type="text" name="ci_cpt_portfolio_project_repeatable_title[]" value="" class="widefat" /></label>
					<label><?php _e( 'Description:', 'ci_theme' ); ?> <input type="text" name="ci_cpt_portfolio_project_repeatable_description[]" value="" class="widefat" /></label>
					<p class="ci-repeating-remove-action"><a href="#" class="button ci-repeating-remove-field"><i class="dashicons dashicons-dismiss"></i><?php _e( 'Remove me', 'ci_theme' ); ?></a></p>
				</div>
		</div>
		<a href="#" class="ci-repeating-add-field button"><i class="dashicons dashicons-plus-alt"></i><?php _e('Add Field', 'ci_theme'); ?></a>
	</fieldset>
	<?php

}
endif;

if ( ! function_exists( 'ci_theme_sanitize_portfolio_project_repeating' ) ) :
function ci_theme_sanitize_portfolio_project_repeating( $POST_array ) {
	if ( empty( $POST_array ) || !is_array( $POST_array ) ) {
		return false;
	}

	$titles       = $POST_array['ci_cpt_portfolio_project_repeatable_title'];
	$descriptions = $POST_array['ci_cpt_portfolio_project_repeatable_description'];

	$count = max( count( $titles ), count( $descriptions ) );

	$new_fields = array();

	$records_count = 0;
	for ( $i = 0; $i < $count; $i++ ) {
		if( empty( $descriptions[ $i ] ) )
			continue;

		$new_fields[ $records_count ]['title']       = sanitize_text_field( $titles[ $i ] );
		$new_fields[ $records_count ]['description'] = wp_kses( $descriptions[ $i ], wp_kses_allowed_html('post') );
		$records_count++;
	}
	return $new_fields;
}
endif;
?>