<?php
//
// Team Post Type related functions.
//
add_action( 'init', 'ci_create_cpt_team' );
add_action( 'admin_init', 'ci_add_cpt_team_meta' );
add_action( 'save_post', 'ci_update_cpt_team_meta' );

if ( ! function_exists( 'ci_create_cpt_team' ) ) :
function ci_create_cpt_team() {
	$labels = array(
		'name'               => _x( 'Team', 'post type general name', 'ci_theme' ),
		'singular_name'      => _x( 'Member', 'post type singular name', 'ci_theme' ),
		'add_new'            => __( 'Add New', 'ci_theme' ),
		'add_new_item'       => __( 'Add New Member', 'ci_theme' ),
		'edit_item'          => __( 'Edit Member', 'ci_theme' ),
		'new_item'           => __( 'New Member', 'ci_theme' ),
		'view_item'          => __( 'View Member', 'ci_theme' ),
		'search_items'       => __( 'Search Members', 'ci_theme' ),
		'not_found'          => __( 'No Members found', 'ci_theme' ),
		'not_found_in_trash' => __( 'No Members found in the trash', 'ci_theme' ),
		'parent_item_colon'  => ''
	);

	$args = array(
		'labels'          => $labels,
		'singular_label'  => __( 'Member', 'ci_theme' ),
		'public'          => true,
		'show_ui'         => true,
		'capability_type' => 'post',
		'hierarchical'    => false,
		'has_archive'     => false,
		'rewrite'         => array( 'slug' => _x( 'member', 'post type slug', 'ci_theme' ) ),
		'menu_position'   => 5,
		'supports'        => array( 'title', 'editor', 'thumbnail', 'excerpt' ),
		'menu_icon'       => 'dashicons-admin-users'
	);

	register_post_type( 'cpt_team' , $args );
}
endif;


if ( ! function_exists('ci_add_cpt_team_meta') ) :
function ci_add_cpt_team_meta() {
	add_meta_box('ci_cpt_team_meta', __('Member Details', 'ci_theme'), 'ci_add_cpt_team_meta_box', 'cpt_team', 'normal', 'high');
}
endif;

if ( ! function_exists( 'ci_update_cpt_team_meta' ) ):
function ci_update_cpt_team_meta( $post_id )	{
	if ( ! ci_can_save_meta('cpt_team') ) return;

	update_post_meta( $post_id, 'ci_cpt_featured_position', sanitize_key( $_POST['ci_cpt_featured_position'] ) );
	update_post_meta( $post_id, 'ci_cpt_icon', sanitize_html_class( $_POST[ 'ci_cpt_icon' ] ) );

	update_post_meta( $post_id, 'ci_cpt_member_byline', sanitize_text_field( $_POST[ 'ci_cpt_member_byline' ] ) );
	update_post_meta( $post_id, "ci_cpt_team_social_icons", ci_theme_sanitize_team_social_icons( $_POST ) );
}
endif;

if ( ! function_exists( 'ci_add_cpt_team_meta_box' ) ) :
function ci_add_cpt_team_meta_box( $object, $box ) {
	ci_prepare_metabox( 'cpt_team' );

	$opts = array(
		'top'   => __( 'On top (Fullwidth)', 'ci_theme' ),
		'left'  => __( 'On the left of the content', 'ci_theme' ),
		'right' => __( 'On the right of the content', 'ci_theme' ),
	);
	ci_metabox_dropdown('ci_cpt_featured_position', $opts, __('Featured Image Position:', 'ci_theme'));

	ci_metabox_input( 'ci_cpt_icon', sprintf( __( 'Enter an icon code for this post. You can use any icons listed in the <a href="%s" target="_blank">FontAwesome Icon Page here.</a>. Enter the code exactly as you see it written, e.g. fa-support', 'ci_theme'), 'http://fontawesome.io/icons/'), array( 'default' => 'fa-globe' ));

	ci_metabox_input( 'ci_cpt_member_byline', __( 'Provide an optional title for this member (e.g. CEO, Web Designer, etc):', 'ci_theme' ) );
	?>

	<div class="postbox" style="margin-top:20px">
		<div class="handlediv" title="<?php esc_attr_e('Click to toggle', 'ci_theme'); ?>"><br></div>
		<h3 class="hndle"><?php _e('Social Links', 'ci_theme'); ?></h3>
		<div class="inside">
			<p><?php echo sprintf(__('To add icons click on "Add Icon" at the bottom and then insert the <em>Icon code</em> and its <em>Link URL</em>. Icon codes can be found <a target="_blank" href="%s">here</a>, type them exactly as they are shown (with fa- in front), e.g. <strong>fa-facebook</strong>. You can also drag and drop the boxes to rearrange the icons.', 'ci_theme'), 'http://fontawesome.io/icons/#brand'); ?></p>
			<fieldset class="social_links ci-repeating-fields">
				<div class="inner">
					<?php
						$fields = get_post_meta($object->ID, 'ci_cpt_team_social_icons', true);

						if (!empty($fields)) {
							foreach( $fields as $field ) {
								?>
								<div class="post-field">
									<label><?php _e( 'Icon code:', 'ci_theme' ); ?> <input type="text" name="ci_cpt_team_social_icons_repeatable_icon[]" value="<?php echo esc_attr( $field['icon'] ); ?>" class="widefat" /></label>
									<label><?php _e( 'Link URL:', 'ci_theme' ); ?> <input type="text" name="ci_cpt_team_social_icons_repeatable_url[]" value="<?php echo esc_attr( $field['url'] ); ?>" class="widefat" /></label>
									<p class="ci-repeating-remove-action"><a href="#" class="button ci-repeating-remove-field"><i class="dashicons dashicons-dismiss"></i><?php _e( 'Remove me', 'ci_theme' ); ?></a></p>
								</div>
								<?php
							}
						}
						?>
						<div class="post-field field-prototype" style="display: none;">
							<label><?php _e( 'Icon code:', 'ci_theme' ); ?> <input type="text" name="ci_cpt_team_social_icons_repeatable_icon[]" value="" class="widefat" /></label>
							<label><?php _e( 'Link URL:', 'ci_theme' ); ?> <input type="text" name="ci_cpt_team_social_icons_repeatable_url[]" value="" class="widefat" /></label>
							<p class="ci-repeating-remove-action"><a href="#" class="button ci-repeating-remove-field"><i class="dashicons dashicons-dismiss"></i><?php _e( 'Remove me', 'ci_theme' ); ?></a></p>
						</div>
				</div>
				<a href="#" class="ci-repeating-add-field button"><i class="dashicons dashicons-plus-alt"></i><?php _e('Add Icon', 'ci_theme'); ?></a>
			</fieldset>
		</div>
	</div>
	<?php
}
endif;

if ( ! function_exists( 'ci_theme_sanitize_team_social_icons' ) ) :
function ci_theme_sanitize_team_social_icons( $POST_array ) {
	if ( empty( $POST_array ) || !is_array( $POST_array ) ) {
		return false;
	}

	$icons = $POST_array['ci_cpt_team_social_icons_repeatable_icon'];
	$urls  = $POST_array['ci_cpt_team_social_icons_repeatable_url'];

	$count = max( count( $icons ), count( $urls ) );

	$new_fields = array();

	$records_count = 0;
	for ( $i = 0; $i < $count; $i++ ) {
		if( empty( $icons[ $i ] ) )
			continue;

		$new_fields[ $records_count ]['icon'] = sanitize_key( $icons[ $i ] );
		$new_fields[ $records_count ]['url']  = esc_url_raw( $urls[ $i ] );
		$records_count++;
	}
	return $new_fields;
}
endif;
?>