<?php if ( woocommerce_enabled() ):
	add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-slider' );

	// Skip the default woocommerce styling and use our boilerplate.
	// Also remove any other redundant styles or scripts
	add_filter( 'woocommerce_enqueue_styles', 'ci_deregister_woocommerce_styles' );
	if ( !function_exists( 'ci_deregister_woocommerce_styles' ) ):
	function ci_deregister_woocommerce_styles( $array ) {
		unset( $array['woocommerce-layout'] );
		unset( $array['woocommerce-smallscreen'] );
		unset( $array['woocommerce-general'] );
		return $array;
	}
	endif;

	// Change number of columns in product loop
	add_filter( 'loop_shop_columns', 'ci_loop_show_columns' );
	if ( !function_exists( 'ci_loop_show_columns' ) ):
	function ci_loop_show_columns() {
		return ci_setting( 'product_columns' );
	}
	endif;

	// Set the number of cross sells product count and columns (in cart page) to the same number as the shop columns.
	// Related and Upsells are set to the same number directly from their respective template files.
	add_filter( 'woocommerce_cross_sells_total', 'ci_woocommerce_cross_sells_columns' );
	add_filter( 'woocommerce_cross_sells_columns', 'ci_woocommerce_cross_sells_columns' );
	if ( !function_exists( 'ci_woocommerce_cross_sells_columns' ) ):
	function ci_woocommerce_cross_sells_columns( $posts_per_page ) {
		return ci_setting( 'product_columns' );
	}
	endif;

	// Remove result count, e.g. "Showing 1–10 of 22 results", added manually
	remove_action( 'woocommerce_before_shop_loop', 'woocommerce_result_count', 20 );
	add_action( 'woocommerce_before_shop_loop', 'ci_woocommerce_shop_actions', 20 );
	if ( !function_exists( 'ci_woocommerce_shop_actions' ) ):
	function ci_woocommerce_shop_actions() {
		?>
		<div class="actions">

			<?php woocommerce_result_count(); ?>

			<div class="product-number">
				<span><?php _e( 'View:', 'ci_theme' ); ?></span>
				<a href="<?php echo esc_url( add_query_arg('view', ci_setting('eshop_products_view_first'), get_permalink( ci_translate_post_id( wc_get_page_id( 'shop' ), true, 'page' ) ) ) ); ?>"><?php ci_e_setting('eshop_products_view_first'); ?></a>
				<a href="<?php echo esc_url( add_query_arg('view', ci_setting('eshop_products_view_second'), get_permalink( ci_translate_post_id( wc_get_page_id( 'shop' ), true, 'page' ) ) ) ); ?>"><?php ci_e_setting('eshop_products_view_second'); ?></a>
				<?php if ( ci_setting('eshop_products_view_all') ) : ?>
					<a href="<?php echo esc_url( add_query_arg('view', 'all', get_permalink( ci_translate_post_id( wc_get_page_id( 'shop' ), true, 'page' ) ) ) ); ?>"><?php _e('All', 'ci_theme'); ?></a>
				<?php endif; ?>
			</div>

		</div><!-- .actions -->
		<?php
	}
	endif;

	// Move the closing link tag that surrounds the product, after the thumbnail.
	remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_product_link_close', 5 );
	add_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_link_close', 20 );

	// We don't need the Rating and Add to Cart button in the listing.
	remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 5 );
	remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 10 );

	// We don't need the coupon form in the checkout page. It's included in the cart page.
	remove_action( 'woocommerce_before_checkout_form', 'woocommerce_checkout_coupon_form', 10 );

	// Remove breadcrumbs.
	remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20 );

	// Move meta above the title.
	remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_meta', 40 );
	add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_meta', 3 );

	// Remove star rating.
	remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_rating', 10 );

	// Move sale flash after the image.
	//remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10 );
	//add_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 20 );

	// Move cross sell display from collaterals to right after the table.
	remove_action( 'woocommerce_cart_collaterals', 'woocommerce_cross_sell_display' );
	add_action( 'woocommerce_after_cart_table', 'woocommerce_cross_sell_display' );


	if ( ! function_exists( 'woocommerce_template_loop_product_title' ) ):
	function woocommerce_template_loop_product_title() {
		echo '<p class="item-title">' . get_the_title() . '</p>';
	}
	endif;


	if (  ! function_exists( 'woocommerce_template_loop_category_title' ) ):
	function woocommerce_template_loop_category_title( $category ) {
		?>
		<p class="item-title">
			<?php
				echo $category->name;
			?>
		</p>
		<p class="item-meta">
			<?php
				if ( $category->count > 0 )
					echo apply_filters( 'woocommerce_subcategory_count_html', ' <mark class="count">(' . $category->count . ')</mark>', $category );
			?>
		</p>
		<?php
	}
	endif;


	// Wrap the sale flash in a span.
	add_filter( 'woocommerce_sale_flash', 'ci_woocommerce_sale_flash', 10 );
	if ( !function_exists( 'ci_woocommerce_sale_flash' ) ):
	function ci_woocommerce_sale_flash( $html ) {
		$html = '<span class="sale-wrap">' . $html . '</span>';

		return $html;
	}
	endif;

	// Override the product thumbnail hooked function, as we want to change its output.
	if ( !function_exists( 'woocommerce_template_loop_product_thumbnail' ) ):
	function woocommerce_template_loop_product_thumbnail() {
		global $product, $post;
		?>
		<figure class="item-thumb">
			<?php echo woocommerce_get_product_thumbnail(); ?>
		</figure>
		<?php
	}
	endif;

	// Add an overlay (zoom icon) in single product images and thumbs.
	add_filter( 'woocommerce_single_product_image_html', 'ci_woocommerce_single_product_image_html', 10 );
	add_filter( 'woocommerce_single_product_image_thumbnail_html', 'ci_woocommerce_single_product_image_html', 10 );
	if ( !function_exists( 'ci_woocommerce_single_product_image_html' ) ):
	function ci_woocommerce_single_product_image_html( $html ) {
		$html = str_replace( '</a>', '<span class="img-overlay"></span></a>', $html );

		return $html;
	}
	endif;

	// Replace the default placeholder image with ours (it has the right dimensions).
	add_filter( 'woocommerce_placeholder_img_src', 'ci_change_woocommerce_placeholder_img_src' );
	if ( !function_exists( 'ci_change_woocommerce_placeholder_img_src' ) ):
	function ci_change_woocommerce_placeholder_img_src( $src ) {
		return get_theme_file_uri( '/images/placeholder.png' );
	}
	endif;

	// Remove width and height from the placeholder image.
	add_filter( 'woocommerce_placeholder_img', 'ci_woocommerce_placeholder_img' );
	if ( !function_exists( 'ci_woocommerce_placeholder_img' ) ):
	function ci_woocommerce_placeholder_img( $html ) {
		$html = preg_replace( '/width="[[:alnum:]%]*"/', '', $html );
		$html = preg_replace( '/height="[[:alnum:]%]*"/', '', $html );

		return $html;
	}
	endif;


	// Make some WooCommerce pages get the fullwidth template
	add_filter( 'template_include', 'ci_theme_wc_cart_fullwidth' );
	if ( !function_exists( 'ci_theme_wc_cart_fullwidth' ) ):
	function ci_theme_wc_cart_fullwidth( $template ) {
		$located = get_child_or_parent_file_path( 'template-fullwidth.php' );

		if ( woocommerce_enabled() and ( is_cart() OR is_checkout() OR is_account_page() ) and !empty( $located ) ) {
			return $located;
		}

		return $template;
	}
	endif;

	// Change posts_per_page and column number on related products
	add_filter( 'woocommerce_output_related_products_args', 'ci_output_related_products_args' );
	if ( !function_exists( 'ci_output_related_products_args' ) ):
	function ci_output_related_products_args( $args ) {
		$args[ 'posts_per_page' ] = 3;
		$args[ 'columns' ]        = 3;
		return $args;
	}
	endif;

	// Change columns on upsell products
	add_filter( 'woocommerce_upsells_columns', 'ci_woocommerce_up_sells_columns' );
	if ( !function_exists( 'ci_woocommerce_up_sells_columns' ) ):
	function ci_woocommerce_up_sells_columns( $columns ) {
		$columns = 3;
		return $columns;
	}
	endif;

	// Change posts_per_page on upsell products
	add_filter( 'woocommerce_upsells_total', 'ci_woocommerce_upsells_total' );
	if ( !function_exists( 'ci_woocommerce_upsells_total' ) ):
	function ci_woocommerce_upsells_total( $limit ) {
		$limit = 3;
		return $limit;
	}
	endif;

endif; // woocommerce_enabled()
?>
