jQuery(window).on("load", function() {
	"use strict";

	/* -----------------------------------------
	 FlexSlider Init
	 ----------------------------------------- */
	var homeSlider = jQuery('.home-slider');
	if ( homeSlider.length ) {
		homeSlider.flexslider( {
			controlNav  : true,
			directionNav: false,
			prevText    : '',
			nextText    : '',
			animation: ThemeOption.slider_effect,
			direction: ThemeOption.slider_direction,
			slideshow: Boolean(ThemeOption.slider_autoslide),
			slideshowSpeed: Number(ThemeOption.slider_speed),
			animationSpeed: Number(ThemeOption.slider_duration),
			pauseOnHover: true,
			start: function( slider ) {
				slider.removeClass( 'loading' );
			},
			after: function( slider ){
				var currentSlide = slider.slides.eq(slider.currentSlide);
				currentSlide.siblings().each(function() {
					var src = jQuery(this).find('iframe').attr('src');
					jQuery(this).find('iframe').attr('src',src);
				});
			}
		});
	}

	var testimonialSlider = jQuery('.testimonials');
	if ( testimonialSlider.length ) {
		testimonialSlider.flexslider( {
			controlNav: false,
			prevText  : '',
			nextText  : ''
		} );
	}

	var portfolioSlider = jQuery('.portfolio-slider');
	if ( portfolioSlider.length ) {
		portfolioSlider.flexslider({
			controlNav: false,
			prevText  : '',
			nextText  : ''
		});
	}

	/* -----------------------------------------
	 Filtering functionality
	 ----------------------------------------- */
	if ( jQuery(".filters-nav").length ) {
		var $container = jQuery('.item-list');
		$container.isotope();

		// filter items when filter link is clicked
		jQuery('.filters-nav li a').click(function(){
			var selector = jQuery(this).attr('data-filter');
			jQuery(this).parent().siblings().find('a').removeClass('selected');
			jQuery(this).addClass("selected");

			$container.isotope({
				filter          : selector,
				animationOptions: {
					duration: 750,
					easing  : 'linear',
					queue   : false
				}
			});

			return false;
		});
	}

	/* -----------------------------------------
	 Parallax
	 ----------------------------------------- */
	function initParallax() {
		jQuery('.parallax').each(function() {
			var $self = jQuery(this),
				offsetCoords = $self.offset(),
				yPos = 0,
				topOffset = offsetCoords.top,
				speed = jQuery(this).data('speed');

			$self.css('backgroundPosition', '50% 0');
			var lastScrollTop = 0,
				$window = jQuery(window);

			$window.scroll(function() {
				// If this section is in view
				if ( ($window.scrollTop() + $window.height()) > (topOffset) && (( topOffset + $self.height()) > $window.scrollTop() )) {

					var current = $self.css('backgroundPosition').split(" ");
					current = current[1].replace('px', '');

					var st = jQuery(this).scrollTop();
					if (st > lastScrollTop) {
						// Down
						yPos = (parseInt(current, 10) - speed);
						if ( yPos > $self.height() ) { yPos = $self.height(); }
					} else {
						// Up
						yPos = (parseInt(current, 10) + speed);
						if ( yPos > 0 ) { yPos = 0; }
					}
					lastScrollTop = st;

					var coords = '50% '+ yPos + 'px';

					// Move the background
					$self.css({ backgroundPosition: coords });
				}
			});
		});
	}

	if ( jQuery(window).width() > 767 ) {
		initParallax();
	}

	/* -----------------------------------------
	 Equalize Heights
	 ----------------------------------------- */
	jQuery(".item-list").find("div[class^='col']").matchHeight();
});

jQuery(document).ready(function($) {
	"use strict";

	var $body = $( 'body' );

	/* -----------------------------------------
	 Sticky header
	 ----------------------------------------- */
	$(".header").waypoint('sticky', {
		offset: 43
	});

	/* -----------------------------------------
	 Responsive Menus Init with mmenu
	 ----------------------------------------- */
	var mainNav = $("#navigation"),
		mobileNav = $("#mobilemenu");

	mainNav.clone().removeAttr('id').removeClass().appendTo(mobileNav);
	mobileNav.find('li').removeAttr('id');

	mobileNav.mmenu({
		offCanvas: {
			position : 'top',
			zposition: 'front'
		}
	});

	/* -----------------------------------------
	 Main Navigation Init
	 ----------------------------------------- */
	$('#navigation').superfish({
		delay      : 300,
		animation  : { opacity: 'show', height: 'show' },
		speed      : 'fast',
		dropShadows: false
	});

	/* -----------------------------------------
	 Responsive Videos with fitVids
	 ----------------------------------------- */
	$body.fitVids();

	/* -----------------------------------------
	 General Lightbox
	 ----------------------------------------- */
	var zoomOptions = {
		show_title        : false,
		hook              : 'data-rel',
		social_tools      : false,
		theme             : 'pp_woocommerce',
		horizontal_padding: 20,
		opacity           : 0.8,
		deeplinking       : false
	};

	var pp_images = $("a[data-rel^='prettyPhoto']");
	if (pp_images.length) {
		pp_images.prettyPhoto(zoomOptions);
	}

	/* -----------------------------------------
	 Zoom single product thumbnails
	 ----------------------------------------- */
	$( '.woocommerce-product-gallery--with-images' ).prepend( '<a href="#" class="woocommerce-product-gallery__trigger"><i class="fa fa-search-plus"></i></a>' );

	$body.on( 'click', '.woocommerce-product-gallery__trigger', function ( e ) {
		var images = $( '.woocommerce-product-gallery__image' ).map(function () {
			return $( this ).find( 'a' ).attr( 'href' );
		} );

		if ( ! $.fn.prettyPhoto.open ) {
			$.fn.prettyPhoto( zoomOptions );
		}

		if ( 1 === images.length ) {
			var currentImageIndex = $( '.woocommerce-product-gallery__image' ).index();
		} else {
			var currentImageIndex = $( '.flex-active-slide' ).index();
		}

		$.prettyPhoto.open( images, null, null, currentImageIndex );
		e.preventDefault();
	} );

	/* -----------------------------------------
	 Contact Map Init
	 ----------------------------------------- */
	var contact_map = $("#map");
	if ( contact_map.length ) {
		var lat = contact_map.data('lat'),
			lng = contact_map.data('lng'),
			tipText = contact_map.data('tooltip-txt'),
			titleText = contact_map.attr('title');

		map_init('map', lat, lng, tipText, titleText);
	}

});


function map_init(mapID, lat, lng, tipText, titleText) {
	'use strict';
	if ( typeof google === 'object' && typeof google.maps === 'object' ) {
		var myLatlng = new google.maps.LatLng( lat, lng );
		var mapOptions = {
			scrollwheel: false,
			zoom       : 8,
			center     : myLatlng,
			mapTypeId  : google.maps.MapTypeId.ROADMAP,
			styles     : [
				{"stylers": [{"saturation": -100}, {"gamma": 1}]},
				{
					"elementType": "labels.text.stroke",
					"stylers"    : [{"visibility": "off"}]
				},
				{
					"featureType": "poi.business",
					"elementType": "labels.text",
					"stylers"    : [{"visibility": "off"}]
				},
				{
					"featureType": "poi.business",
					"elementType": "labels.icon",
					"stylers"    : [{"visibility": "off"}]
				},
				{
					"featureType": "poi.place_of_worship",
					"elementType": "labels.text",
					"stylers"    : [{"visibility": "off"}]
				},
				{
					"featureType": "poi.place_of_worship",
					"elementType": "labels.icon",
					"stylers"    : [{"visibility": "off"}]
				},
				{
					"featureType": "road",
					"elementType": "geometry",
					"stylers"    : [{"visibility": "simplified"}]
				},
				{
					"featureType": "water",
					"stylers"    : [{"visibility": "on"}, {"saturation": 50}, {"gamma": 0}, {"hue": "#50a5d1"}]
				},
				{
					"featureType": "administrative.neighborhood",
					"elementType": "labels.text.fill",
					"stylers"    : [{"color": "#333333"}]
				},
				{
					"featureType": "road.local",
					"elementType": "labels.text",
					"stylers"    : [{"weight": 0.5}, {"color": "#333333"}]
				},
				{
					"featureType": "transit.station",
					"elementType": "labels.icon",
					"stylers"    : [{"gamma": 1}, {"saturation": 0}]
				}
			]
		};

		var map = new google.maps.Map( document.getElementById( mapID ), mapOptions );

		var contentString = '<div class="content">' + tipText + '</div>';

		var infowindow = new google.maps.InfoWindow( {
			content: contentString
		} );

		var marker = new google.maps.Marker( {
			position: myLatlng, map: map, title: titleText
		} );

		google.maps.event.addListener( marker, 'click', function() {
			infowindow.open( map, marker );
		} );
	}
}
