<?php
/*
 * Template Name: Post type Listing
 */
?>

<?php get_header(); ?>

<?php while ( have_posts() ) : the_post(); ?>
	<?php
		$post_type      = get_post_meta( get_the_ID(), 'listing_post_type', true );
		$layout         = get_post_meta( get_the_ID(), 'listing_layout', true );
		$columns        = get_post_meta( get_the_ID(), 'listing_columns', true );
		$posts_per_page = get_post_meta( get_the_ID(), 'listing_posts_per_page', true );
		$isotope        = get_post_meta( get_the_ID(), 'listing_isotope', true );

		$row_class = '';
		if ( 'on' == $isotope ) {
			$row_class .= ' isotope ';
		}

		$item_classes = '';
		switch ( $columns ) {
			case 2:
				$item_classes = 'col-xs-12 col-sm-6';
				break;
			case 3:
				$item_classes = 'col-xs-12 col-sm-6 col-md-4';
				break;
			case 4:
				$item_classes = 'col-xs-12 col-sm-6 col-md-3';
				break;
		}


		$args = array(
			'paged'     => ci_get_page_var(),
			'post_type' => $post_type,
		);

		if ( $posts_per_page >= 1 ) {
			$args['posts_per_page'] = $posts_per_page;
		} elseif ( $posts_per_page <= -1 ) {
			$args['posts_per_page'] = -1;
		}

		if ( 'on' == $isotope || 'sidebar' == $layout ) {
			$args['posts_per_page'] = -1;
		}

		$q = new WP_Query( $args );

		$cpt_taxonomy = ''; // We need this defined early, so that we can check its content even if isotope is disabled.
	?>
	<main class="main">
		<div class="container">
			<div class="row">

				<?php if ( 'columns' == $layout ) : ?>

					<?php if ( 'on' == $isotope && ! wp_is_mobile() ) : ?>
						<?php
							$cpt_taxonomy = get_object_taxonomies( $post_type );
							if ( is_array( $cpt_taxonomy ) && count( $cpt_taxonomy ) > 0 ) {
								$cpt_taxonomy = $cpt_taxonomy[0];
							} else {
								$cpt_taxonomy = '';
							}
						?>
						<?php if ( ! empty( $cpt_taxonomy ) ): ?>
							<?php $cats = get_terms( $cpt_taxonomy, array( 'hide_empty' => 1 ) ); ?>
							<div class="col-xs-12">
								<h2 class="section-title"><?php the_title(); ?></h2>

								<ul class="filters-nav group">
									<li><a href="#filter" class="selected btn btn-sm transparent" data-filter="*"><?php esc_html_e( 'All Items', 'ci_theme' ); ?></a></li>

									<?php foreach ( $cats as $cat ) : ?>
										<li><a href="#filter" data-filter=".term-<?php echo esc_attr( $cat->term_id ); ?>" class="btn btn-sm transparent"><?php echo esc_html( $cat->name ); ?></a></li>
									<?php endforeach; ?>
								</ul>
							</div>
						<?php endif; ?>
					<?php endif; ?>

					<div class="col-xs-12">
						<?php if ( 'on' != $isotope || empty( $cpt_taxonomy ) ) : ?>
							<?php get_template_part( 'inc_section_titles' ); ?>
						<?php endif; ?>

						<div class="row item-list <?php echo esc_attr( $row_class ); ?>">
							<?php while ( $q->have_posts() ) : $q->the_post(); ?>
								<?php
									$terms_classes = '';
									if ( 'on' == $isotope && ! empty( $cpt_taxonomy ) ) {
										$terms         = get_the_terms( get_the_ID(), $cpt_taxonomy );
										$terms         = ! empty( $terms ) ? $terms : array();
										$terms_classes = implode( ' ', array_map( 'urldecode', wp_list_pluck( $terms, 'slug' ) ) );
										foreach ( wp_list_pluck( $terms, 'term_id' ) as $term_id ) {
											$terms_classes .= ' term-' . $term_id;
										}
									}
								?>
								<div class="<?php echo esc_attr( $item_classes ); ?> <?php echo esc_attr( $terms_classes ); ?>">
									<?php get_template_part( 'listing', get_post_type() ); ?>
								</div>
							<?php endwhile; ?>
						</div>
					</div>

				<?php elseif ( 'sidebar' == $layout ) : ?>

					<div class="col-md-8">
						<?php get_template_part( 'inc_section_titles' ); ?>

						<?php while ( $q->have_posts() ) : $q->the_post(); ?>
							<?php
								$current_ID = get_the_ID();
								$fi_layout  = get_post_meta( get_the_ID(), 'ci_cpt_featured_position', true );

								$thumb_class = $fi_layout == 'top' ? 'entry-thumb' : 'entry-thumb-content-' . $fi_layout;
								$thumb_size  = $fi_layout == 'top' ? 'post-thumbnail' : 'thumbnail';
							?>
							<article id="entry-<?php the_ID(); ?>" <?php post_class( 'entry' ); ?>>
								<h1 class="entry-title"><?php the_title(); ?></h1>

								<?php if ( 'cpt_team' == $post_type ) : ?>
									<?php $position = get_post_meta( get_the_ID(), 'ci_cpt_member_byline', true ); ?>
									<?php if ( ! empty( $position ) ) : ?>
										<div class="entry-meta"><?php echo esc_html( $position ); ?></div>
									<?php endif; ?>

									<?php $fields = get_post_meta( get_the_ID(), 'ci_cpt_team_social_icons', true ); ?>
									<?php if ( ! empty( $fields ) ) : ?>
										<div class="member-socials">
											<?php foreach ( $fields as $field ) : ?>
												<a class="member-social" href="<?php echo esc_url( $field['url'] ); ?>"><i class="fa <?php echo esc_attr( $field['icon'] ); ?>"></i></a>
											<?php endforeach; ?>
										</div>
									<?php endif; ?>
								<?php endif; ?>


								<?php if ( has_post_thumbnail() ) : ?>
									<figure class="<?php echo esc_attr( $thumb_class ); ?>">
										<a href="<?php echo esc_url( ci_get_featured_image_src( 'large' ) ); ?>" data-rel="prettyPhoto">
										<?php the_post_thumbnail( $thumb_size ); ?>
										</a>
									</figure>
								<?php endif; ?>

								<div class="entry-content">
									<?php the_content(); ?>
								</div>
							</article>
							<?php break; // We only want the first post in this section, so break out of the loop. ?>
						<?php endwhile; ?>
					</div>

					<?php $q->rewind_posts(); ?>

					<div class="col-md-4">
						<div class="sidebar">
							<?php if ( $q->have_posts() ) : ?>
								<ul class="item-nav">
									<?php while ( $q->have_posts() ) : $q->the_post(); ?>
										<?php $icon = get_post_meta( get_the_ID(), 'ci_cpt_icon', true ); ?>
										<li>
											<a <?php echo ( get_the_ID() == $current_ID ? 'class="active"' : '' ); ?> href="<?php the_permalink(); ?>">
												<?php
													 if ( ! empty( $icon ) ) {
														 echo '<i class="fa '. esc_attr( $icon ) . '"></i>';
													 }
												?>
												<?php the_title(); ?>
											</a>
										</li>
									<?php endwhile; ?>
								</ul>
							<?php endif; wp_reset_postdata(); ?>
						</div>
					</div>

				<?php endif; ?>

			</div>
		</div>
	</main>

<?php endwhile; ?>

<?php get_footer(); ?>
